## 0.5.0 - 2023-03-13

### Added

- [#748](https://github.com/edgarrmondragon/citric/issues/748) Support custom JSON encoders
- [#745](https://github.com/edgarrmondragon/citric/issues/745) Annotate some responses with `TypedDict`
